stage: structure: stage-1: mongo_node [DB] merchants [collection] scene-1 [collection] scene-2 [DB] merchants-squashes [collection] squash-1 [{ "public": "3043300506032b6571033a005bed4824c5853fd1a296d25ba0f64e9a36781ce9d7268182f67b7485670f4d9d4cba600b5393c768660a175289bbf63bddead92210bdab6900", "amount": "120304030" },{ "public": "", "amount": "120304030" },{ "public": "", "amount": "123" }] [collection] squash-2 [DB] escrow [collection] scene-1 [collection] scene-2 [DB] escrow-squashes [collection] squash-1 agenda: [ ] prompt QR codes for signing